pub enum WaitlistReason {
EligibleSegmentFull,
}Expand description
Reasons a boarding request should be waitlisted instead of confirmed.
Variants
EligibleSegmentFull
The room type is valid for the pet, but all matching rooms are occupied.